import { XPromiseStateEnum } from './utils';

export type XPromiseExecutor<T> = (resolve: (value: T) => void, reject: (reason: any) => void) => void;
/** 原始引用信息 */
export interface XPromiseRawRefInfo<T> {
    /** promise */
    promise: Promise<T>;
    /** 超时定时器 */
    timeoutTimer?: number;
    /** resolve包装方法 */
    resolveWrap: (value: T) => void;
    /** reject包装方法 */
    rejectWrap: (reason: any) => void;
    /** promise then */
    promiseThen: Promise<T>["then"];
    /** promise catch */
    promiseCatch: Promise<T>["catch"];
    /** promise finally */
    promiseFinally: Promise<T>["finally"];
}
/** base信息 */
export interface XPromiseBaseInfo<T> extends XPromiseRawRefInfo<T> {
    /** 清除超时定时器 */
    clearTimeoutTimer: () => void;
    /** 开始时间 */
    startTime: number;
    /** 结束时间 */
    endTime?: number;
    /** 状态 */
    state: XPromiseStateEnum;
    /** 数量 */
    num: number;
    /** 索引 */
    index: number;
}
export interface XPromiseRawContext<T> {
    baseInfo: XPromiseBaseInfo<T>;
}
export declare const createXPromiseRawInfo: <T>() => Partial<XPromiseRawRefInfo<T>>;
/** 创建 XPromiseRawInfo */
export declare const createXPromiseRawContext: <T>(executorRaw: XPromiseExecutor<T>) => XPromiseRawContext<T>;
